# 蜘蛛网

#### 介绍
beautifulsoup4 的草蟒中文版

#### 安装教程

`python -m pip install -U grasspy-bs4`

#### 使用说明

1.  [bs4 使用指南](https://www.crummy.com/software/BeautifulSoup/bs4/doc/#)
2.  [参考示例见代码仓库 tests 文件夹](https://gitee.com/laowu2019_admin/zwbs)

